import openai
from .utils import build_message_dict, get_answer_from_model


class ContextualGPT:
    def __init__(self, system_task, api_key):
        self._system_task = system_task
        self.conversation = [build_message_dict("system", self._system_task)]
        self.api_key = api_key

        openai.api_key = self.api_key

    @property
    def system_task(self):
        return self._system_task

    @system_task.setter
    def system_task(self, task):
        self._system_task = task

    def ask(self, question, verbose=True):
        self.conversation.append(build_message_dict("user", question))

        answer = get_answer_from_model(
            self.conversation,
            question,
        )
        print(answer) if verbose else None

        self.conversation.append(build_message_dict("assistant", answer))

    def ask_previous(self, question):
        self.conversation.pop()
        self.ask(question)

    def flush_conversation(self):
        self.conversation = [build_message_dict("system", self.task)]



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pygptwrapper']

package_data = \
{'': ['*']}

install_requires = \
['openai>=0.27.1,<0.28.0']

setup_kwargs = {
    'name': 'pygptwrapper',
    'version': '0.1.0',
    'description': 'Python Wrapper for the ChatGPT API',
    'long_description': '# pyGPT - A Python Wrapper for the ChatGPT API\npyGPT is a Python library that provides a simple way to interact with the ChatGPT API, which is a powerful language model trained by OpenAI that can generate human-like text based on input prompts.\n\nThis library makes it easy to integrate the ChatGPT API into your Python applications, allowing you to generate text in real-time, create chatbots, or automate text generation tasks.\n\n# Installation\nTo install pyGPT, you can use pip:\n\n```\npip install pyGPT\n```',
    'author': 'Your Name',
    'author_email': 'you@example.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



import openai

MODEL = "gpt-3.5-turbo"


def build_message_dict(role, content):
    return {
        "role": role,
        "content": content,
    }


def get_answer_from_model(conversation, question):
    openai_object = openai.ChatCompletion.create(
        model=MODEL,
        messages=conversation,
    )
    return openai_object["choices"][0]["message"]["content"]
